@@ -20,42 +20,39 @@
 
 // within each specialisation of the Proxy class:
 //
-// elem_type        = the type of the elements obtained from object Q
-// pod_type         = the underlying type of elements if elem_type is std::complex
-// stored_type      = the type of the Q object
-// ea_type          = the type of the object that provides access to elements via
-// operator[i] aligned_ea_type  = the type of the object that provides access to elements
-// via at_alt(i)
+// elem_type        = type of the elements obtained from object Q
+// pod_type         = underlying type of elements if elem_type is std::complex
+// stored_type      = type of Q object
+// ea_type          = type of object that provides access to elements via operator[i]
+// aligned_ea_type  = type of object that provides access to elements via at_alt(i)
 //
-// use_at           = boolean indicating whether at(row,col) must be used to get elements
-// use_mp           = boolean indicating whether OpenMP can be used while processing
-// elements has_subview      = boolean indicating whether the Q object has a subview
+// use_at           = boolean to indicate at(row,col) must be used to get elements
+// use_mp           = boolean to indicate OpenMP can be used while processing elements
+// has_subview      = boolean to indicate Q object has a subview
 //
-// is_row           = boolean indicating whether the Q object can be treated a row vector
-// is_col           = boolean indicating whether the Q object can be treated a column
-// vector is_xvec          = boolean indicating whether the Q object is a vector with
-// unknown orientation
+// is_row           = boolean to indicate Q object can be treated a row vector
+// is_col           = boolean to indicate Q object can be treated a column vector
+// is_xvec          = boolean to indicate Q object is a vector with unknown orientation
 //
-// Q                = object that can be unwrapped via the unwrap family of classes (ie. Q
+// Q                = object that can be unwrapped via unwrap family of classes (ie. Q
 // must be convertible to Mat)
 //
-// get_n_rows()     = return the number of rows in Q
-// get_n_cols()     = return the number of columns in Q
-// get_n_elem()     = return the number of elements in Q
+// get_n_rows()     = return number of rows in Q
+// get_n_cols()     = return number of columns in Q
+// get_n_elem()     = return number of elements in Q
 //
-// operator[i]      = linear element accessor; valid only if the 'use_at' boolean is false
-// at(row,col)      = access elements via (row,col); valid only if the 'use_at' boolean is
-// true at_alt(i)        = aligned linear element accessor; valid only if the 'use_at'
-// boolean is false and is_aligned() returns true
+// operator[i]      = linear element accessor; valid only if 'use_at' boolean is false
+// at(row,col)      = access elements via (row,col); valid only if 'use_at' boolean is
+// true at_alt(i)        = aligned linear element accessor; valid only if 'use_at' boolean
+// is false and is_aligned() returns true
 //
-// get_ea()         = return the object that provides linear access to elements via
-// operator[i] get_aligned_ea() = return the object that provides linear access to
-// elements via at_alt(i); valid only if is_aligned() returns true
+// get_ea()         = return object that provides linear access to elements via
+// operator[i] get_aligned_ea() = return object that provides linear access to elements
+// via at_alt(i); valid only if is_aligned() returns true
 //
-// is_alias(X)      = return true/false indicating whether the Q object aliases matrix X
-// has_overlap(X)   = return true/false indicating whether the Q object has overlap with
-// subview X is_aligned()     = return true/false indicating whether the Q object has
-// aligned memory
+// is_alias(X)      = return true/false to indicate Q object aliases matrix X
+// has_overlap(X)   = return true/false to indicate Q object has overlap with subview X
+// is_aligned()     = return true/false to indicate Q object has aligned memory
 
 template <typename T1>
 struct Proxy_default {
@@ -80,7 +77,7 @@ struct Proxy_fixed {
 
   arma_aligned const T1& Q;
 
-  inline explicit Proxy_fixed(const T1& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy_fixed(const T1& A) : Q(A) { arma_debug_sigprint(); }
 
   //// this may require T1::n_elem etc to be declared as static constexpr inline variables
   ///(C++17) / see also the notes in Mat::fixed /
@@ -157,7 +154,7 @@ struct Proxy<Mat<eT> > {
 
   arma_aligned const Mat<eT>& Q;
 
-  inline explicit Proxy(const Mat<eT>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const Mat<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   arma_inline uword get_n_cols() const { return Q.n_cols; }
@@ -172,7 +169,7 @@ struct Proxy<Mat<eT> > {
 
   template <typename eT2>
   arma_inline bool is_alias(const Mat<eT2>& X) const {
-    return (is_same_type<eT, eT2>::value) ? (void_ptr(&Q) == void_ptr(&X)) : false;
+    return (is_same_type<eT, eT2>::yes) && (void_ptr(&Q) == void_ptr(&X));
   }
 
   template <typename eT2>
@@ -201,7 +198,7 @@ struct Proxy<Col<eT> > {
 
   arma_aligned const Col<eT>& Q;
 
-  inline explicit Proxy(const Col<eT>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const Col<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   constexpr uword get_n_cols() const { return 1; }
@@ -216,7 +213,7 @@ struct Proxy<Col<eT> > {
 
   template <typename eT2>
   arma_inline bool is_alias(const Mat<eT2>& X) const {
-    return (is_same_type<eT, eT2>::value) ? (void_ptr(&Q) == void_ptr(&X)) : false;
+    return (is_same_type<eT, eT2>::yes) && (void_ptr(&Q) == void_ptr(&X));
   }
 
   template <typename eT2>
@@ -245,7 +242,7 @@ struct Proxy<Row<eT> > {
 
   arma_aligned const Row<eT>& Q;
 
-  inline explicit Proxy(const Row<eT>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const Row<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   constexpr uword get_n_rows() const { return 1; }
   arma_inline uword get_n_cols() const { return Q.n_cols; }
@@ -260,7 +257,7 @@ struct Proxy<Row<eT> > {
 
   template <typename eT2>
   arma_inline bool is_alias(const Mat<eT2>& X) const {
-    return (is_same_type<eT, eT2>::value) ? (void_ptr(&Q) == void_ptr(&X)) : false;
+    return (is_same_type<eT, eT2>::yes) && (void_ptr(&Q) == void_ptr(&X));
   }
 
   template <typename eT2>
@@ -289,9 +286,7 @@ struct Proxy<Gen<T1, gen_type> > {
 
   arma_aligned const Gen<T1, gen_type>& Q;
 
-  inline explicit Proxy(const Gen<T1, gen_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
-  }
+  inline explicit Proxy(const Gen<T1, gen_type>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return (is_row ? 1 : Q.n_rows); }
   arma_inline uword get_n_cols() const { return (is_col ? 1 : Q.n_cols); }
@@ -337,9 +332,7 @@ struct Proxy<eOp<T1, eop_type> > {
 
   arma_aligned const eOp<T1, eop_type>& Q;
 
-  inline explicit Proxy(const eOp<T1, eop_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
-  }
+  inline explicit Proxy(const eOp<T1, eop_type>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.get_n_rows(); }
   arma_inline uword get_n_cols() const { return is_col ? 1 : Q.get_n_cols(); }
@@ -384,7 +377,7 @@ struct Proxy<eGlue<T1, T2, eglue_type> > {
   arma_aligned const eGlue<T1, T2, eglue_type>& Q;
 
   inline explicit Proxy(const eGlue<T1, T2, eglue_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.get_n_rows(); }
@@ -429,7 +422,7 @@ struct Proxy<Op<T1, op_type> > {
 
   arma_aligned const Mat<elem_type> Q;
 
-  inline explicit Proxy(const Op<T1, op_type>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const Op<T1, op_type>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
   arma_inline uword get_n_cols() const { return is_col ? 1 : Q.n_cols; }
@@ -474,7 +467,7 @@ struct Proxy<Glue<T1, T2, glue_type> > {
   arma_aligned const Mat<elem_type> Q;
 
   inline explicit Proxy(const Glue<T1, T2, glue_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
@@ -527,9 +520,9 @@ struct Proxy<Glue<T1, T2, glue_min> > {
   arma_lt_comparator<elem_type> comparator;
 
   inline explicit Proxy(const this_Glue_type& X) : Q(X), P1(X.A), P2(X.B) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
 
-    arma_debug_assert_same_size(P1, P2, "element-wise min()");
+    arma_conform_assert_same_size(P1, P2, "element-wise min()");
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : P1.get_n_rows(); }
@@ -594,9 +587,9 @@ struct Proxy<Glue<T1, T2, glue_max> > {
   arma_gt_comparator<elem_type> comparator;
 
   inline explicit Proxy(const this_Glue_type& X) : Q(X), P1(X.A), P2(X.B) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
 
-    arma_debug_assert_same_size(P1, P2, "element-wise max()");
+    arma_conform_assert_same_size(P1, P2, "element-wise max()");
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : P1.get_n_rows(); }
@@ -654,7 +647,7 @@ struct Proxy<mtOp<out_eT, T1, op_type> > {
   arma_aligned const Mat<out_eT> Q;
 
   inline explicit Proxy(const mtOp<out_eT, T1, op_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
@@ -700,7 +693,7 @@ struct Proxy<mtGlue<out_eT, T1, T2, glue_type> > {
   arma_aligned const Mat<out_eT> Q;
 
   inline explicit Proxy(const mtGlue<out_eT, T1, T2, glue_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
@@ -746,7 +739,7 @@ struct Proxy<CubeToMatOp<T1, op_type> > {
   arma_aligned const Mat<elem_type> Q;
 
   inline explicit Proxy(const CubeToMatOp<T1, op_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
@@ -783,7 +776,7 @@ struct Proxy<CubeToMatOp<T1, op_vectorise_cube_col> > {
 
   static constexpr bool use_at = false;
   static constexpr bool use_mp = false;
-  static constexpr bool has_subview = false;
+  static constexpr bool has_subview = true;
 
   static constexpr bool is_row = false;
   static constexpr bool is_col = true;
@@ -794,7 +787,7 @@ struct Proxy<CubeToMatOp<T1, op_vectorise_cube_col> > {
 
   inline explicit Proxy(const CubeToMatOp<T1, op_vectorise_cube_col>& A)
       : U(A.m), Q(const_cast<elem_type*>(U.M.memptr()), U.M.n_elem, 1, false, true) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -839,9 +832,7 @@ struct Proxy<SpToDOp<T1, op_type> > {
 
   arma_aligned const Mat<elem_type> Q;
 
-  inline explicit Proxy(const SpToDOp<T1, op_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
-  }
+  inline explicit Proxy(const SpToDOp<T1, op_type>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
   arma_inline uword get_n_cols() const { return is_col ? 1 : Q.n_cols; }
@@ -867,9 +858,9 @@ struct Proxy<SpToDOp<T1, op_type> > {
   arma_inline bool is_aligned() const { return memory::is_aligned(Q.memptr()); }
 };
 
-template <typename T1>
-struct Proxy<SpToDOp<T1, op_nonzeros_spmat> > {
-  typedef typename T1::elem_type elem_type;
+template <typename eT>
+struct Proxy<SpToDOp<SpMat<eT>, op_sp_nonzeros> > {
+  typedef eT elem_type;
   typedef typename get_pod_type<elem_type>::result pod_type;
   typedef Mat<elem_type> stored_type;
   typedef const elem_type* ea_type;
@@ -877,18 +868,18 @@ struct Proxy<SpToDOp<T1, op_nonzeros_spmat> > {
 
   static constexpr bool use_at = false;
   static constexpr bool use_mp = false;
-  static constexpr bool has_subview = false;
+  static constexpr bool has_subview = true;
 
   static constexpr bool is_row = false;
   static constexpr bool is_col = true;
   static constexpr bool is_xvec = false;
 
-  arma_aligned const unwrap_spmat<T1> U;
+  arma_aligned const SpMat<elem_type>& R;
   arma_aligned const Mat<elem_type> Q;
 
-  inline explicit Proxy(const SpToDOp<T1, op_nonzeros_spmat>& A)
-      : U(A.m), Q(const_cast<elem_type*>(U.M.values), U.M.n_nonzero, 1, false, true) {
-    arma_extra_debug_sigprint();
+  inline explicit Proxy(const SpToDOp<SpMat<eT>, op_sp_nonzeros>& A)
+      : R(A.m), Q(const_cast<elem_type*>(R.values), R.n_nonzero, 1, false, true) {
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -934,7 +925,7 @@ struct Proxy<SpToDGlue<T1, T2, glue_type> > {
   arma_aligned const Mat<elem_type> Q;
 
   inline explicit Proxy(const SpToDGlue<T1, T2, glue_type>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
@@ -979,7 +970,7 @@ struct Proxy<subview<eT> > {
 
   arma_aligned const subview<eT>& Q;
 
-  inline explicit Proxy(const subview<eT>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const subview<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   arma_inline uword get_n_cols() const { return Q.n_cols; }
@@ -994,7 +985,7 @@ struct Proxy<subview<eT> > {
 
   template <typename eT2>
   arma_inline bool is_alias(const Mat<eT2>& X) const {
-    return (is_same_type<eT, eT2>::value) ? (void_ptr(&(Q.m)) == void_ptr(&X)) : false;
+    return (is_same_type<eT, eT2>::yes) && (void_ptr(&(Q.m)) == void_ptr(&X));
   }
 
   template <typename eT2>
@@ -1023,7 +1014,7 @@ struct Proxy<subview_col<eT> > {
 
   arma_aligned const subview_col<eT>& Q;
 
-  inline explicit Proxy(const subview_col<eT>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const subview_col<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   constexpr uword get_n_cols() const { return 1; }
@@ -1038,7 +1029,7 @@ struct Proxy<subview_col<eT> > {
 
   template <typename eT2>
   arma_inline bool is_alias(const Mat<eT2>& X) const {
-    return (is_same_type<eT, eT2>::value) ? (void_ptr(&(Q.m)) == void_ptr(&X)) : false;
+    return (is_same_type<eT, eT2>::yes) && (void_ptr(&(Q.m)) == void_ptr(&X));
   }
 
   template <typename eT2>
@@ -1070,7 +1061,7 @@ struct Proxy<subview_cols<eT> > {
 
   inline explicit Proxy(const subview_cols<eT>& A)
       : sv(A), Q(const_cast<eT*>(A.colptr(0)), A.n_rows, A.n_cols, false, false) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -1086,7 +1077,7 @@ struct Proxy<subview_cols<eT> > {
 
   template <typename eT2>
   arma_inline bool is_alias(const Mat<eT2>& X) const {
-    return (is_same_type<eT, eT2>::value) ? (void_ptr(&(sv.m)) == void_ptr(&X)) : false;
+    return (is_same_type<eT, eT2>::yes) && (void_ptr(&(sv.m)) == void_ptr(&X));
   }
 
   template <typename eT2>
@@ -1115,7 +1106,7 @@ struct Proxy<subview_row<eT> > {
 
   arma_aligned const subview_row<eT>& Q;
 
-  inline explicit Proxy(const subview_row<eT>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const subview_row<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   constexpr uword get_n_rows() const { return 1; }
   arma_inline uword get_n_cols() const { return Q.n_cols; }
@@ -1130,7 +1121,7 @@ struct Proxy<subview_row<eT> > {
 
   template <typename eT2>
   arma_inline bool is_alias(const Mat<eT2>& X) const {
-    return (is_same_type<eT, eT2>::value) ? (void_ptr(&(Q.m)) == void_ptr(&X)) : false;
+    return (is_same_type<eT, eT2>::yes) && (void_ptr(&(Q.m)) == void_ptr(&X));
   }
 
   template <typename eT2>
@@ -1161,13 +1152,13 @@ struct Proxy<subview_elem1<eT, T1> > {
   arma_aligned const Proxy<T1> R;
 
   inline explicit Proxy(const subview_elem1<eT, T1>& A) : Q(A), R(A.a.get_ref()) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
 
     const bool R_is_vec = ((R.get_n_rows() == 1) || (R.get_n_cols() == 1));
     const bool R_is_empty = (R.get_n_elem() == 0);
 
-    arma_debug_check(((R_is_vec == false) && (R_is_empty == false)),
-                     "Mat::elem(): given object must be a vector");
+    arma_conform_check(((R_is_vec == false) && (R_is_empty == false)),
+                       "Mat::elem(): given object must be a vector");
   }
 
   arma_inline uword get_n_rows() const { return R.get_n_elem(); }
@@ -1176,17 +1167,17 @@ struct Proxy<subview_elem1<eT, T1> > {
 
   arma_inline elem_type operator[](const uword i) const {
     const uword ii = (Proxy<T1>::use_at) ? R.at(i, 0) : R[i];
-    arma_debug_check_bounds((ii >= Q.m.n_elem), "Mat::elem(): index out of bounds");
+    arma_conform_check_bounds((ii >= Q.m.n_elem), "Mat::elem(): index out of bounds");
     return Q.m[ii];
   }
   arma_inline elem_type at(const uword r, const uword) const {
     const uword ii = (Proxy<T1>::use_at) ? R.at(r, 0) : R[r];
-    arma_debug_check_bounds((ii >= Q.m.n_elem), "Mat::elem(): index out of bounds");
+    arma_conform_check_bounds((ii >= Q.m.n_elem), "Mat::elem(): index out of bounds");
     return Q.m[ii];
   }
   arma_inline elem_type at_alt(const uword i) const {
     const uword ii = (Proxy<T1>::use_at) ? R.at(i, 0) : R[i];
-    arma_debug_check_bounds((ii >= Q.m.n_elem), "Mat::elem(): index out of bounds");
+    arma_conform_check_bounds((ii >= Q.m.n_elem), "Mat::elem(): index out of bounds");
     return Q.m[ii];
   }
 
@@ -1225,7 +1216,7 @@ struct Proxy<subview_elem2<eT, T1, T2> > {
   arma_aligned const Mat<eT> Q;
 
   inline explicit Proxy(const subview_elem2<eT, T1, T2>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -1270,7 +1261,7 @@ struct Proxy<diagview<eT> > {
 
   arma_aligned const diagview<eT>& Q;
 
-  inline explicit Proxy(const diagview<eT>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const diagview<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   constexpr uword get_n_cols() const { return 1; }
@@ -1285,7 +1276,7 @@ struct Proxy<diagview<eT> > {
 
   template <typename eT2>
   arma_inline bool is_alias(const Mat<eT2>& X) const {
-    return (is_same_type<eT, eT2>::value) ? (void_ptr(&(Q.m)) == void_ptr(&X)) : false;
+    return (is_same_type<eT, eT2>::yes) && (void_ptr(&(Q.m)) == void_ptr(&X));
   }
 
   template <typename eT2>
@@ -1321,7 +1312,7 @@ struct Proxy_diagvec_mat<Op<T1, op_diagvec> > {
   arma_aligned const diagview<elem_type> Q;
 
   inline explicit Proxy_diagvec_mat(const Op<T1, op_diagvec>& A) : R(A.m), Q(R.diag()) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -1372,7 +1363,7 @@ struct Proxy_diagvec_expr<Op<T1, op_diagvec> > {
   arma_aligned const Mat<elem_type> Q;
 
   inline explicit Proxy_diagvec_expr(const Op<T1, op_diagvec>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -1419,7 +1410,7 @@ struct Proxy<Op<T1, op_diagvec> >
       Proxy_diagvec;
 
   inline explicit Proxy(const Op<T1, op_diagvec>& A) : Proxy_diagvec(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 };
 
@@ -1441,9 +1432,7 @@ struct Proxy<Op<T1, op_diagvec2> > {
 
   arma_aligned const Mat<elem_type> Q;
 
-  inline explicit Proxy(const Op<T1, op_diagvec2>& A) : Q(A) {
-    arma_extra_debug_sigprint();
-  }
+  inline explicit Proxy(const Op<T1, op_diagvec2>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   constexpr uword get_n_cols() const { return 1; }
@@ -1494,7 +1483,7 @@ struct Proxy_xtrans_default<Op<T1, op_htrans> > {
   const xtrans_mat<elem_type, true> Q;
 
   inline explicit Proxy_xtrans_default(const Op<T1, op_htrans>& A) : U(A.m), Q(U.M) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline ea_type get_ea() const { return Q; }
@@ -1533,7 +1522,7 @@ struct Proxy_xtrans_default<Op<T1, op_strans> > {
   const xtrans_mat<elem_type, false> Q;
 
   inline explicit Proxy_xtrans_default(const Op<T1, op_strans>& A) : U(A.m), Q(U.M) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline ea_type get_ea() const { return Q; }
@@ -1580,7 +1569,7 @@ struct Proxy_xtrans_vector<Op<T1, op_htrans> > {
   inline Proxy_xtrans_vector(const Op<T1, op_htrans>& A)
       : U(A.m),
         Q(const_cast<elem_type*>(U.M.memptr()), U.M.n_cols, U.M.n_rows, false, false) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline ea_type get_ea() const { return Q.memptr(); }
@@ -1622,7 +1611,7 @@ struct Proxy_xtrans_vector<Op<T1, op_strans> > {
   inline Proxy_xtrans_vector(const Op<T1, op_strans>& A)
       : U(A.m),
         Q(const_cast<elem_type*>(U.M.memptr()), U.M.n_cols, U.M.n_rows, false, false) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline ea_type get_ea() const { return Q.memptr(); }
@@ -1682,7 +1671,7 @@ struct Proxy<Op<T1, op_htrans> >
   using Proxy_xtrans::Q;
 
   inline explicit Proxy(const Op<T1, op_htrans>& A) : Proxy_xtrans(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
@@ -1738,7 +1727,7 @@ struct Proxy<Op<T1, op_strans> >
   using Proxy_xtrans::Q;
 
   inline explicit Proxy(const Op<T1, op_strans>& A) : Proxy_xtrans(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.n_rows; }
@@ -1787,7 +1776,7 @@ struct Proxy_subview_row_htrans_cx {
 
   inline explicit Proxy_subview_row_htrans_cx(const Op<subview_row<eT>, op_htrans>& A)
       : Q(A.m) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   template <typename eT2>
@@ -1821,7 +1810,7 @@ struct Proxy_subview_row_htrans_non_cx {
 
   inline explicit Proxy_subview_row_htrans_non_cx(const Op<subview_row<eT>, op_htrans>& A)
       : Q(A.m) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   template <typename eT2>
@@ -1871,7 +1860,7 @@ struct Proxy<Op<subview_row<eT>, op_htrans> >
   using Proxy_sv_row_ht::Q;
 
   inline explicit Proxy(const Op<subview_row<eT>, op_htrans>& A) : Proxy_sv_row_ht(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -1917,7 +1906,7 @@ struct Proxy<Op<subview_row<eT>, op_strans> > {
   arma_aligned const subview_row_strans<eT> Q;
 
   inline explicit Proxy(const Op<subview_row<eT>, op_strans>& A) : Q(A.m) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -1967,7 +1956,7 @@ struct Proxy<Op<Row<std::complex<T> >, op_htrans> > {
 
   inline explicit Proxy(const Op<Row<std::complex<T> >, op_htrans>& A)
       : Q(A.m.memptr(), A.m.n_rows, A.m.n_cols), src(A.m) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -2017,7 +2006,7 @@ struct Proxy<Op<Col<std::complex<T> >, op_htrans> > {
 
   inline explicit Proxy(const Op<Col<std::complex<T> >, op_htrans>& A)
       : Q(A.m.memptr(), A.m.n_rows, A.m.n_cols), src(A.m) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   constexpr uword get_n_rows() const { return 1; }
@@ -2067,7 +2056,7 @@ struct Proxy<Op<subview_col<std::complex<T> >, op_htrans> > {
 
   inline explicit Proxy(const Op<subview_col<std::complex<T> >, op_htrans>& A)
       : Q(A.m.colptr(0), A.m.n_rows, A.m.n_cols), src(A.m) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   constexpr uword get_n_rows() const { return 1; }
@@ -2116,7 +2105,7 @@ struct Proxy<Op<T1, op_htrans2> > {
   arma_aligned const eOp<Op<T1, op_htrans>, eop_scalar_times> Q;
 
   inline explicit Proxy(const Op<T1, op_htrans2>& A) : R(A.m), Q(R, A.aux) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return is_row ? 1 : Q.get_n_rows(); }
@@ -2161,9 +2150,7 @@ struct Proxy<subview_row_strans<eT> > {
 
   arma_aligned const subview_row_strans<eT>& Q;
 
-  inline explicit Proxy(const subview_row_strans<eT>& A) : Q(A) {
-    arma_extra_debug_sigprint();
-  }
+  inline explicit Proxy(const subview_row_strans<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   constexpr uword get_n_cols() const { return 1; }
@@ -2207,9 +2194,7 @@ struct Proxy<subview_row_htrans<eT> > {
 
   arma_aligned const subview_row_htrans<eT>& Q;
 
-  inline explicit Proxy(const subview_row_htrans<eT>& A) : Q(A) {
-    arma_extra_debug_sigprint();
-  }
+  inline explicit Proxy(const subview_row_htrans<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   constexpr uword get_n_cols() const { return 1; }
@@ -2254,7 +2239,7 @@ struct Proxy<xtrans_mat<eT, do_conj> > {
   arma_aligned const Mat<eT> Q;
 
   inline explicit Proxy(const xtrans_mat<eT, do_conj>& A) : Q(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -2299,7 +2284,7 @@ struct Proxy<xvec_htrans<eT> > {
 
   arma_aligned const Mat<eT> Q;
 
-  inline explicit Proxy(const xvec_htrans<eT>& A) : Q(A) { arma_extra_debug_sigprint(); }
+  inline explicit Proxy(const xvec_htrans<eT>& A) : Q(A) { arma_debug_sigprint(); }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
   arma_inline uword get_n_cols() const { return Q.n_cols; }
@@ -2351,7 +2336,7 @@ struct Proxy_vectorise_col_mat<Op<T1, op_vectorise_col> > {
 
   inline explicit Proxy_vectorise_col_mat(const Op<T1, op_vectorise_col>& A)
       : U(A.m), Q(const_cast<elem_type*>(U.M.memptr()), U.M.n_elem, 1, false, false) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return Q.n_rows; }
@@ -2404,7 +2389,7 @@ struct Proxy_vectorise_col_expr<Op<T1, op_vectorise_col> > {
 
   inline explicit Proxy_vectorise_col_expr(const Op<T1, op_vectorise_col>& A)
       : Q(A), R(A.m) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 
   arma_inline uword get_n_rows() const { return R.get_n_elem(); }
@@ -2452,7 +2437,7 @@ struct Proxy<Op<T1, op_vectorise_col> >
       Op<T1, op_vectorise_col>, (Proxy<T1>::use_at)>::result Proxy_vectorise_col;
 
   inline explicit Proxy(const Op<T1, op_vectorise_col>& A) : Proxy_vectorise_col(A) {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
   }
 };
 
